==> jscad__io-utils-2.0.10.jar: META-INF/resources/webjars/jscad__io-utils/2.0.10/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.0.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.9...@jscad/io-utils@2.0.10) (2021-11-07)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.8...@jscad/io-utils@2.0.9) (2021-10-17)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.7...@jscad/io-utils@2.0.8) (2021-10-04)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.6...@jscad/io-utils@2.0.7) (2021-09-27)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.5...@jscad/io-utils@2.0.6) (2021-09-09)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.4...@jscad/io-utils@2.0.5) (2021-06-20)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.3...@jscad/io-utils@2.0.4) (2021-06-11)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.2...@jscad/io-utils@2.0.3) (2021-06-01)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.0...@jscad/io-utils@2.0.2) (2021-04-20)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.0...@jscad/io-utils@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.11...@jscad/io-utils@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.10...@jscad/io-utils@2.0.0-alpha.11) (2021-03-07)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.9...@jscad/io-utils@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.8...@jscad/io-utils@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.7...@jscad/io-utils@2.0.0-alpha.8) (2020-12-04)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.6...@jscad/io-utils@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.5...@jscad/io-utils@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/io/issues/705)) ([62017a4](https://github.com/jscad/io/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.4...@jscad/io-utils@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.4](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.3...@jscad/io-utils@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.3](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.2...@jscad/io-utils@2.0.0-alpha.3) (2020-09-19)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.2](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.1...@jscad/io-utils@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.1](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.0...@jscad/io-utils@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/io-utils





# 2.0.0-alpha.0 (2020-08-13)

### Features

* **io:** move most of io code from core/io to io/io-utils





<a name="0.1.3"></a>
## [0.1.3](https://github.com/jscad/io/compare/@jscad/io-utils@0.1.2...@jscad/io-utils@0.1.3) (2018-09-02)


### Bug Fixes

* **svg deserializer:** fixed svg-deserializer to work with Inkscape files ([#72](https://github.com/jscad/io/issues/72)) ([f35ea5e](https://github.com/jscad/io/commit/f35ea5e))




<a name="0.1.2"></a>
## [0.1.2](https://github.com/jscad/io/compare/@jscad/io-utils@0.1.1...@jscad/io-utils@0.1.2) (2017-11-04)




**Note:** Version bump only for package @jscad/io-utils

<a name="0.1.1"></a>
## [0.1.1](https://github.com/jscad/io/compare/@jscad/io-utils@0.1.0...@jscad/io-utils@0.1.1) (2017-10-30)




**Note:** Version bump only for package @jscad/io-utils

<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/io-utils@0.0.4...@jscad/io-utils@0.1.0) (2017-10-15)


### Features

* **stl-deserializer:** add ability to deserialize stl to csg ([#32](https://github.com/jscad/io/issues/32)) ([a90dcf4](https://github.com/jscad/io/commit/a90dcf4))




<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/io-utils@0.0.3...@jscad/io-utils@0.0.4) (2017-10-10)




**Note:** Version bump only for package @jscad/io-utils

<a name="0.0.3"></a>
## 0.0.3 (2017-10-10)




**Note:** Version bump only for package @jscad/io-utils

==> jscad__io-utils-2.0.12.jar: META-INF/resources/webjars/jscad__io-utils/2.0.12/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.0.12](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.11...@jscad/io-utils@2.0.12) (2021-12-26)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.10...@jscad/io-utils@2.0.11) (2021-12-11)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.9...@jscad/io-utils@2.0.10) (2021-11-07)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.8...@jscad/io-utils@2.0.9) (2021-10-17)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.7...@jscad/io-utils@2.0.8) (2021-10-04)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.6...@jscad/io-utils@2.0.7) (2021-09-27)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.5...@jscad/io-utils@2.0.6) (2021-09-09)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.4...@jscad/io-utils@2.0.5) (2021-06-20)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.3...@jscad/io-utils@2.0.4) (2021-06-11)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.2...@jscad/io-utils@2.0.3) (2021-06-01)

**Note:** Version bump only for package @jscad/io-utils





## [2.0.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.0...@jscad/io-utils@2.0.2) (2021-04-20)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.0...@jscad/io-utils@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.11...@jscad/io-utils@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.10...@jscad/io-utils@2.0.0-alpha.11) (2021-03-07)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.9...@jscad/io-utils@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.8...@jscad/io-utils@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.7...@jscad/io-utils@2.0.0-alpha.8) (2020-12-04)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/io-utils@2.0.0-alpha.6...@jscad/io-utils@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.5...@jscad/io-utils@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/io/issues/705)) ([62017a4](https://github.com/jscad/io/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.4...@jscad/io-utils@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.4](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.3...@jscad/io-utils@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.3](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.2...@jscad/io-utils@2.0.0-alpha.3) (2020-09-19)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.2](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.1...@jscad/io-utils@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/io-utils





# [2.0.0-alpha.1](https://github.com/jscad/io/compare/@jscad/io-utils@2.0.0-alpha.0...@jscad/io-utils@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/io-utils





# 2.0.0-alpha.0 (2020-08-13)

### Features

* **io:** move most of io code from core/io to io/io-utils





<a name="0.1.3"></a>
## [0.1.3](https://github.com/jscad/io/compare/@jscad/io-utils@0.1.2...@jscad/io-utils@0.1.3) (2018-09-02)


### Bug Fixes

* **svg deserializer:** fixed svg-deserializer to work with Inkscape files ([#72](https://github.com/jscad/io/issues/72)) ([f35ea5e](https://github.com/jscad/io/commit/f35ea5e))




<a name="0.1.2"></a>
## [0.1.2](https://github.com/jscad/io/compare/@jscad/io-utils@0.1.1...@jscad/io-utils@0.1.2) (2017-11-04)




**Note:** Version bump only for package @jscad/io-utils

<a name="0.1.1"></a>
## [0.1.1](https://github.com/jscad/io/compare/@jscad/io-utils@0.1.0...@jscad/io-utils@0.1.1) (2017-10-30)




**Note:** Version bump only for package @jscad/io-utils

<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/io-utils@0.0.4...@jscad/io-utils@0.1.0) (2017-10-15)


### Features

* **stl-deserializer:** add ability to deserialize stl to csg ([#32](https://github.com/jscad/io/issues/32)) ([a90dcf4](https://github.com/jscad/io/commit/a90dcf4))




<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/io-utils@0.0.3...@jscad/io-utils@0.0.4) (2017-10-10)




**Note:** Version bump only for package @jscad/io-utils

<a name="0.0.3"></a>
## 0.0.3 (2017-10-10)




**Note:** Version bump only for package @jscad/io-utils
